.. _all-salt.serializers:

================================
Full list of builtin serializers
================================

.. currentmodule:: salt.serializers

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    json
    msgpack
    yaml
    yamlex